@@ -6,7 +6,7 @@ use Exporter ();
 
 {
     no strict "vars";
-    $VERSION = '0.50';
+    $VERSION = '0.51';
     @ISA = qw< Exporter Class::Accessor >;
 
     %EXPORT_TAGS = (
@@ -1435,15 +1435,15 @@ C<ROTATION_NONE> - no rotation
 
 =item *
 
-C<ROTATION_90> - rotate by 90
+C<ROTATION_90> - rotate by 90E<deg>
 
 =item *
 
-C<ROTATION_180> - rotate by 180
+C<ROTATION_180> - rotate by 180E<deg>
 
 =item *
 
-C<ROTATION_270> - rotate by 270
+C<ROTATION_270> - rotate by 270E<deg>
 
 =back
 
@@ -1515,7 +1515,7 @@ L<http://www.bradyid.com/bradyid/downloads/downloadsPageView.do?file=TLSPCLink_P
 
 Please report any bugs or feature requests to
 C<bug-device-tlsprinter at rt.cpan.org>, or through the web interface at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Device-TLSPrinter>.
+L<https://rt.cpan.org/Dist/Display.html?Name=Device-TLSPrinter>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -1530,22 +1530,26 @@ You can also look for information at:
 
 =over
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item * MetaCPAN
 
-L<http://annocpan.org/dist/Device-TLSPrinter>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Device-TLSPrinter>
-
-=item * RT: CPAN's request tracker
-
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Device-TLSPrinter>
+L<https://metacpan.org/module/Device::TLSPrinter>
 
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/Device-TLSPrinter>
 
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Device-TLSPrinter>
+
+=item * RT: CPAN's request tracker
+
+L<https://rt.cpan.org/Dist/Display.html?Name=Device-TLSPrinter>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Device-TLSPrinter>
+
 =back
 
 
@@ -1556,7 +1560,7 @@ SE<eacute>bastien Aperghis-Tramoni, C<< <sebastien (at) aperghis.net> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2011 SE<eacute>bastien Aperghis-Tramoni, all rights reserved.
+Copyright 2006-2012 SE<eacute>bastien Aperghis-Tramoni, all rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
